==> 0.9.3.tar.gz: lib/src/components/show_actions_sheet.dart <==
import 'package:flutter/cupertino.dart';

import '../utils/utils.dart';
import '../waff_localizations.dart';

/// Actions sheet pops up from the bottom of the screen
///
/// ```
/// enum MyActions { UPDATE, DELETE }
///
/// Future<void> openActionDialog() async {
///   switch (await showActionsSheet([
///     ActionSheetItem(type: MyActions.UPDATE, text: 'Update'),
///     ActionSheetItem(type: MyActions.DELETE, text: 'Delete'),
///   ])) {
///     case MyActions.UPDATE:
///     // implement ...
///       break;
///     case MyActions.DELETE:
///     // implement ...
///       break;
///   }
/// }
/// ```
Future<dynamic> showActionsSheet(List<ActionSheetItem> actions,
    {bool disabledCancel = false,
    String? cancelText,
    TextStyle? cancelStyle}) async {
  List<Widget> actionsWidget = [];
  actions.forEach((item) {
    actionsWidget.add(
      CupertinoActionSheetAction(
        onPressed: () async {
          Navigator.pop(await getxContext, item.type);
        },
        child: Text(item.text, style: item.style),
      ),
    );
  });

  return await showCupertinoModalPopup(
      context: await getxContext,
      builder: (context) {
        return CupertinoActionSheet(
          actions: actionsWidget,
          cancelButton: false == disabledCancel
              ? CupertinoActionSheetAction(
                  onPressed: () {
                    Navigator.pop(context, null);
                  },
                  child: Text(
                    cancelText ?? WaffLocalizations.S('cancel'),
                    style: cancelStyle,
                  ),
                )
              : null,
        );
      });
}

class ActionSheetItem {
  final dynamic type;
  final String text;
  final TextStyle? style;

  ActionSheetItem({required this.type, required this.text, this.style});
}

==> 0.10.0.tar.gz: lib/src/components/show_actions_sheet.dart <==
import 'package:flutter/cupertino.dart';

import '../utils/utils.dart';
import '../waff_localizations.dart';

/// Actions sheet pops up from the bottom of the screen
///
/// ```
/// enum MyActions { UPDATE, DELETE }
///
/// Future<void> openActionDialog() async {
///   switch (await showActionsSheet<MyActions>([
///     ActionSheetItem(value: MyActions.UPDATE, text: 'Update'),
///     ActionSheetItem(value: MyActions.DELETE, text: 'Delete'),
///   ])) {
///     case MyActions.UPDATE:
///     // implement ...
///       break;
///     case MyActions.DELETE:
///     // implement ...
///       break;
///   }
/// }
/// ```
Future<T> showActionsSheet<T>(List<ActionSheetItem<T>> actions,
    {bool disabledCancel = false,
    String? cancelText,
    TextStyle? cancelStyle}) async {
  List<Widget> actionsWidget = [];
  actions.forEach((item) {
    actionsWidget.add(
      CupertinoActionSheetAction(
        onPressed: () async {
          Navigator.pop(await getxContext, item.value);
        },
        child: Text(item.text, style: item.style),
      ),
    );
  });

  return await showCupertinoModalPopup(
      context: await getxContext,
      builder: (context) {
        return CupertinoActionSheet(
          actions: actionsWidget,
          cancelButton: false == disabledCancel
              ? CupertinoActionSheetAction(
                  onPressed: () {
                    Navigator.pop(context, null);
                  },
                  child: Text(
                    cancelText ?? WaffLocalizations.S('cancel'),
                    style: cancelStyle,
                  ),
                )
              : null,
        );
      });
}

class ActionSheetItem<T> {
  final T value;
  final String text;
  final TextStyle? style;

  ActionSheetItem({required this.value, required this.text, this.style});
}
